@@ -134,6 +134,6 @@ class FastTrackerConfiger:
                     else:
                         config_name = functions.lower_case_name(key[12:])
                         setattr(config, config_name, val)
-                        functions.log("config_name:%s,debug_level:%s,enable:%s,debug:%s", config_name, str(config.debug_level),str(config.enable),str(config.debug))
+                        # functions.log("config_name:%s,debug_level:%s,enable:%s,debug:%s", config_name, str(config.debug_level),str(config.enable),str(config.debug))
         except Exception as e:
             functions.log("python探针环境变量读取错误信息：%s", str(e))
