@@ -42,8 +42,8 @@ def install():
             carrier.set_frontend_trace_id(headers[trace_id_name.upper()])
         if trace_name.upper() in headers:
             carrier.set_frontend_trace_id(headers[trace_name.upper()])
-        if "parent_id" in headers:
-            carrier.set_parent_id(headers["parent_id"])
+        # if "parent_id" in headers:
+        #     carrier.set_parent_id(headers["parent_id"])
         from falcon import RequestOptions
         req = request.Request(env, RequestOptions())
         with context.new_entry_span(op=functions.getUri(str(req.url.split("?")[0])), carrier=carrier) as span:
@@ -67,7 +67,11 @@ def install():
                 span.tag(
                     Tag(key=tags.HttpParams, val=params_tostring(req.params)[0:])
                 )
-
+            functions.log("method:%s,context:%s",req.method,req.context)
+            if req.method == "POST":
+                span.tag(
+                    Tag(key=tags.HttpBody, val=req.context)
+                )
             set_code(config.tenant_code_reader, req, "tenant_code")
             set_code(config.user_code_reader, req, "user_code")
             set_code(config.service_version_reader,req,"service_version")
